emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

master 6f48b46b03: ; Fix typos


From: Stefan Kangas
Subject: master 6f48b46b03: ; Fix typos
Date: Fri, 11 Nov 2022 09:55:18 -0500 (EST)

branch: master
commit 6f48b46b03cd58a541684c57e42eb4679794f0fd
Author: Stefan Kangas <stefankangas@gmail.com>
Commit: Stefan Kangas <stefankangas@gmail.com>

    ; Fix typos
---
 ChangeLog.1                   |  2 +-
 ChangeLog.2                   |  2 +-
 ChangeLog.3                   | 28 ++++++++++++++--------------
 doc/emacs/ChangeLog.1         |  2 +-
 doc/emacs/package.texi        |  6 +++---
 doc/misc/ChangeLog.1          |  2 +-
 doc/misc/efaq.texi            |  2 +-
 doc/misc/flymake.texi         |  2 +-
 doc/misc/modus-themes.org     |  6 +++---
 doc/misc/reftex.texi          |  2 +-
 doc/misc/transient.texi       |  2 +-
 etc/NEWS                      |  6 +++---
 etc/TODO                      |  2 +-
 lisp/ChangeLog.15             |  4 ++--
 lisp/ChangeLog.16             |  6 +++---
 lisp/ChangeLog.17             |  2 +-
 lisp/ChangeLog.7              |  8 ++++----
 lisp/ansi-osc.el              |  2 +-
 lisp/calendar/diary-lib.el    |  4 ++--
 lisp/cedet/ede.el             |  2 +-
 lisp/emacs-lisp/smie.el       |  2 +-
 lisp/erc/ChangeLog.1          |  4 ++--
 lisp/eshell/esh-util.el       |  2 +-
 lisp/gnus/ChangeLog.1         |  2 +-
 lisp/gnus/ChangeLog.3         |  4 ++--
 lisp/gnus/nnimap.el           |  2 +-
 lisp/icomplete.el             |  2 +-
 lisp/language/ind-util.el     |  4 ++--
 lisp/leim/quail/indian.el     |  2 +-
 lisp/leim/quail/misc-lang.el  |  2 +-
 lisp/mh-e/ChangeLog.1         |  2 +-
 lisp/org/ChangeLog.1          |  8 ++++----
 lisp/progmodes/cc-bytecomp.el |  2 +-
 lisp/progmodes/cc-engine.el   |  2 +-
 lisp/progmodes/cc-mode.el     |  2 +-
 lisp/progmodes/eglot.el       | 12 ++++++------
 lisp/replace.el               |  2 +-
 nt/inc/ms-w32.h               |  2 +-
 src/ChangeLog.13              |  2 +-
 src/ChangeLog.7               |  8 ++++----
 src/itree.c                   |  6 +++---
 src/w32fns.c                  |  2 +-
 src/xterm.c                   |  2 +-
 test/src/buffer-tests.el      |  2 +-
 44 files changed, 86 insertions(+), 86 deletions(-)

diff --git a/ChangeLog.1 b/ChangeLog.1
index 35533d60ff..a8df1c0420 100644
--- a/ChangeLog.1
+++ b/ChangeLog.1
@@ -930,7 +930,7 @@
        (mostlyclean_dirs, clean_dirs, distclean_dirs, maintainer_clean_dirs):
        New variables.
        (mostlyclean, clean, distclean, bootstrap-clean, maintainer-clean)
-       (extraclean): Define using each subdirectory as a prequisite.
+       (extraclean): Define using each subdirectory as a prerequisite.
        * lib/Makefile.am (bootstrap-clean): New.
 
 2014-06-15  Paul Eggert  <eggert@cs.ucla.edu>
diff --git a/ChangeLog.2 b/ChangeLog.2
index 5a73d53b8b..fc038033ec 100644
--- a/ChangeLog.2
+++ b/ChangeLog.2
@@ -26343,7 +26343,7 @@
        (verilog-type-font-keywords): Cycle delay operators like ##1 and
        ##[0:$] are now highlighted in their entirety similarly to the #
        delay-control operator.  Likewise, the followed-by operators #-#
-       and #=# are no longer partially highlighed.
+       and #=# are no longer partially highlighted.
        (verilog-backward-syntactic-ws-quick)
        (verilog-skip-backward-comments): Minor performance improvements
        to buffer traversal functions for reduced latency.
diff --git a/ChangeLog.3 b/ChangeLog.3
index f2245a4ed5..d90b261da7 100644
--- a/ChangeLog.3
+++ b/ChangeLog.3
@@ -5731,7 +5731,7 @@
 
 2021-10-09  Dmitry Gutov  <dgutov@yandex.ru>
 
-       Slight simplificaiton
+       Slight simplification
 
        * lisp/progmodes/xref.el (xref--insert-xrefs):
        Compute log only once.  Use 'dolist'.
@@ -35728,7 +35728,7 @@
        (comp-arithm-cmp-fun-p, comp-negate-arithm-cmp-fun)
        (comp-reverse-arithm-fun): Rename and add '=' '!='.
        (comp-emit-assume, comp-add-cond-cstrs, comp-fwprop-insn): Update
-       for new function nameing and to handle '='.
+       for new function naming and to handle '='.
        * lisp/emacs-lisp/comp-cstr.el (comp-cstr-=): New function.
        * test/src/comp-tests.el (comp-tests-type-spec-tests): Add a bunch
        of '=' specific tests.
@@ -39854,7 +39854,7 @@
 
        * lisp/net/mairix.el: Use lexical-binding.
        Remove redundant `:group` args.
-       (mairix-widget-create-query): Remove unnused var `allwidgets`.
+       (mairix-widget-create-query): Remove unused var `allwidgets`.
 
 2021-02-09  Juri Linkov  <juri@linkov.net>
 
@@ -49106,7 +49106,7 @@
        (comp-split-pos-neg): Minor.
        (comp-normalize-typeset): Logic update.
        (comp-union-typesets): Minor.
-       (comp-intersect-two-typesets): New functio.
+       (comp-intersect-two-typesets): New function.
        (comp-intersect-typesets): Logic update.
        (comp-range-union, comp-range-intersection): Minor.
        (comp-cstr-union-homogeneous, comp-cstr-union-1-no-mem)
@@ -50911,7 +50911,7 @@
 
 2020-12-12  Lars Ingebrigtsen  <larsi@gnus.org>
 
-       Alter the "Redundant pcase patter" warning message
+       Alter the "Redundant pcase pattern" warning message
 
        * lisp/emacs-lisp/pcase.el (pcase--expand): Make the "Redundant
        pcase pattern" warning less vague (bug#31350).
@@ -77634,7 +77634,7 @@
 
        Add an initial implementation to support dynamic scope.  Arg
        parsing/binding it's done using the existing code in use for
-       bytecode (no ad-hoc code is synthetized for that).
+       bytecode (no ad-hoc code is synthesized for that).
 
        * src/lisp.h (struct Lisp_Subr): Add lambda_list field.
        (SUBR_NATIVE_COMPILED_DYNP): New inliner.
@@ -118316,7 +118316,7 @@
 
        * lisp/mh-e/mh-speed.el (mh-speed-parse-flists-output):
        * lisp/mh-e/mh-search.el (mh-index-parse-search-regexp): Avoid
-       warning about `values-list' by using `cl-values-list' insead.
+       warning about `values-list' by using `cl-values-list' instead.
 
 2019-07-29  Lars Ingebrigtsen  <larsi@gnus.org>
 
@@ -126255,7 +126255,7 @@
 
        Suppress warning about non-prefixed variable in mailalias.el
 
-       * lisp/mail/mailalias.el (patters): Suppress warning about
+       * lisp/mail/mailalias.el (pattern): Suppress warning about
        non-prefixed variable used by `mail-complete-alist'.
 
 2019-06-15  Lars Ingebrigtsen  <larsi@gnus.org>
@@ -130524,7 +130524,7 @@
 
 2019-05-16  Lars Ingebrigtsen  <larsi@gnus.org>
 
-       Avoind string-as-multibyte in ps-output-string-prim
+       Avoid string-as-multibyte in ps-output-string-prim
 
        * lisp/ps-print.el (ps-output-string-prim): Avoid
        `string-as-multibyte', and encode as utf-8 instead if multibyte.
@@ -156879,7 +156879,7 @@
        Merge from origin/emacs-26
 
        90bea37 ; * etc/PROBLEMS: Fix fvwm version number in last commit
-       af82d1f * etc/PROBLEMS: Document stickyness problem with FVWM (Bug#31...
+       af82d1f * etc/PROBLEMS: Document stickiness problem with FVWM (Bug#31...
        4a3aed2 Update Emacs Lisp Intro to match current behavior
        21f2247 Merge branch 'emacs-26' of git.savannah.gnu.org:/srv/git/emac...
        3257085 Fix previous commit
@@ -176909,7 +176909,7 @@
 
 2018-06-02  Martin Rudalics  <rudalics@gmx.at>
 
-       * etc/PROBLEMS: Document stickyness problem with FVWM (Bug#31650)
+       * etc/PROBLEMS: Document stickiness problem with FVWM (Bug#31650)
 
 2018-06-01  Eli Zaretskii  <eliz@gnu.org>
 
@@ -221327,8 +221327,8 @@
        is never used.  Hardcode the syntax so that the compilar can detect such
        dead code and remove it from compiled code.
 
-       The only exception is RE_NO_POSIX_BACKTRACKING which can be separatelly
-       specified.  Handle this separatelly with a function argument (replacing
+       The only exception is RE_NO_POSIX_BACKTRACKING which can be separately
+       specified.  Handle this separately with a function argument (replacing
        now unnecessary syntax argument).
 
        With this patchset, size of Emacs binary on x86_64 machine is reduced by
@@ -227801,7 +227801,7 @@
 
        * lisp/auth-source.el
        (auth-source-macos-keychain-search-items): Handle keychain
-       output correctly when has special chararcters (bug#22824).
+       output correctly when has special characters (bug#22824).
 
 2016-04-24  Magnus Henoch  <magnus.henoch@gmail.com>
 
diff --git a/doc/emacs/ChangeLog.1 b/doc/emacs/ChangeLog.1
index 048b7bd99a..5647538a24 100644
--- a/doc/emacs/ChangeLog.1
+++ b/doc/emacs/ChangeLog.1
@@ -2711,7 +2711,7 @@
        of list-faces-display here, from Standard Faces node.
        Note special role of `default' background.
        (Standard Faces): Note special role of `default' background.
-       Note that region face may be taken fom GTK.  Add xref to Text Display.
+       Note that region face may be taken from GTK.  Add xref to Text Display.
        (Text Scale): Rename from "Temporary Face Changes".
        Callers changed.  Don't bother documenting variable-pitch-mode.
        (Font Lock): Copyedits.  Remove font-lock-maximum-size.
diff --git a/doc/emacs/package.texi b/doc/emacs/package.texi
index e8af35e2e3..f9fa28074f 100644
--- a/doc/emacs/package.texi
+++ b/doc/emacs/package.texi
@@ -588,7 +588,7 @@ the current development head or implement a new feature to 
scratch an
 itch.  If the package metadata indicates how to contact the
 maintainer, you can use the command @code{package-report-bug} to
 report a bug via Email.  This report will include all the user options
-that you have customised.  If you have made a change you wish to share
+that you have customized.  If you have made a change you wish to share
 with the maintainers, first commit your changes then use the command
 @code{package-vc-prepare-patch} to share it.  @xref{Preparing Patches}.
 
@@ -598,6 +598,6 @@ with the maintainers, first commit your changes then use 
the command
 checkout instead of cloning a remote repository.  You can do this by
 using @code{package-vc-install-from-checkout}, which creates a symbolic link
 from the package directory (@pxref{Package Files}) to your checkout
-and initialises the code.  Note that you might have to use
-@code{package-vc-refresh} to repeat the initialisation and update the
+and initializes the code.  Note that you might have to use
+@code{package-vc-refresh} to repeat the initialization and update the
 autoloads.
diff --git a/doc/misc/ChangeLog.1 b/doc/misc/ChangeLog.1
index 1ee3c14fb9..48637ab608 100644
--- a/doc/misc/ChangeLog.1
+++ b/doc/misc/ChangeLog.1
@@ -1460,7 +1460,7 @@
 
 2013-10-24  Michael Albinus  <michael.albinus@gmx.de>
 
-       * ert.texi (Running Tests Interactively): Adapt examle output.
+       * ert.texi (Running Tests Interactively): Adapt example output.
        (Tests and Their Environment): Mention skip-unless.
 
 2013-10-23  Glenn Morris  <rgm@gnu.org>
diff --git a/doc/misc/efaq.texi b/doc/misc/efaq.texi
index 23e3b086a3..3f5c2bc1a7 100644
--- a/doc/misc/efaq.texi
+++ b/doc/misc/efaq.texi
@@ -2668,7 +2668,7 @@ To disable or change the way backups are made,
 @cindex Backup files in a single directory
 You can control where Emacs puts backup files by customizing the
 variable @code{backup-directory-alist}.  This variable's value
-specifies that files whose names match specific patters should have
+specifies that files whose names match specific patterns should have
 their backups put in certain directories.  A typical use is to add the
 element @code{("." . @var{dir})} to force Emacs to put @strong{all}
 backup files in the directory @file{dir}.
diff --git a/doc/misc/flymake.texi b/doc/misc/flymake.texi
index da1695099a..c075f0298a 100644
--- a/doc/misc/flymake.texi
+++ b/doc/misc/flymake.texi
@@ -615,7 +615,7 @@ delimited by @var{beg} and @var{end}.  @var{type} is a 
diagnostic
 symbol (@pxref{Flymake error types}), and @var{text} is a description
 of the problem detected in this region.  Most commonly @var{locus} is
 the buffer object designating for the current buffer being
-syntax-checked.  However, it may be a string nameing a file relative
+syntax-checked.  However, it may be a string naming a file relative
 to the current working directory.  @xref{Foreign and list-only
 diagnostics}, for when this may be useful.  Depending on the type of
 @var{locus}, @var{beg} and @var{end} are both either buffer positions
diff --git a/doc/misc/modus-themes.org b/doc/misc/modus-themes.org
index c5accd0789..56ba5fd348 100644
--- a/doc/misc/modus-themes.org
+++ b/doc/misc/modus-themes.org
@@ -2834,7 +2834,7 @@ To reset the changes, we apply this and reload the theme:
 
 Users who wish to leverage such a mechanism can opt to implement it
 on-demand by means of a global minor mode.  The following snippet covers
-both themes and expands to some more assosiations in the palette:
+both themes and expands to some more associations in the palette:
 
 #+begin_src emacs-lisp
 (define-minor-mode my-modus-themes-tinted
@@ -5878,7 +5878,7 @@ interface virtually unusable.
 
 [[#h:5808be52-361a-4d18-88fd-90129d206f9b][Option for links]].
 
-Again, one must exercise judgement in order to avoid discrimination,
+Again, one must exercise judgment in order to avoid discrimination,
 where "discrimination" refers to:
 
 + The treatment of substantially different magnitudes as if they were of
@@ -5951,7 +5951,7 @@ the themes, which is partially fleshed out in this manual.
 
 With regard to the artistic aspect (where "art" qua skill may amount to
 an imprecise science), there is no hard-and-fast rule in effect as it
-requires one to exercize discretion and make decisions based on
+requires one to exercise discretion and make decisions based on
 context-dependent information or constraints.  As is true with most
 things in life, when in doubt, do not cling on to the letter of the law
 but try to understand its spirit.
diff --git a/doc/misc/reftex.texi b/doc/misc/reftex.texi
index b30e5aeaa4..e85f096f99 100644
--- a/doc/misc/reftex.texi
+++ b/doc/misc/reftex.texi
@@ -3605,7 +3605,7 @@ menu.  @xref{Key Bindings}.
 
 @deffn Command reftex-toc
 Show the table of contents for the current document.  When called with
-one ore two @kbd{C-u} prefixes, rescan the document first.
+one or two @kbd{C-u} prefixes, rescan the document first.
 @end deffn
 
 @deffn Command reftex-label
diff --git a/doc/misc/transient.texi b/doc/misc/transient.texi
index a6745131d8..e5e7cccbe8 100644
--- a/doc/misc/transient.texi
+++ b/doc/misc/transient.texi
@@ -1957,7 +1957,7 @@ probably don't want that.
 @item
 @code{transient-suffix} and @code{transient-non-suffix} play a part when
 determining whether the currently active transient prefix command
-remains active/transient when a suffix or abitrary non-suffix
+remains active/transient when a suffix or arbitrary non-suffix
 command is invoked.  @xref{Transient State}.
 
 @item
diff --git a/etc/NEWS b/etc/NEWS
index 2245b41d9e..0b8f4539f9 100644
--- a/etc/NEWS
+++ b/etc/NEWS
@@ -165,7 +165,7 @@ time.
 +++
 *** New variable 'inhibit-automatic-native-compilation'.
 If set, Emacs will inhibit native compilation (and won't write
-anything to the eln cache automatically).  The variable is initialised
+anything to the eln cache automatically).  The variable is initialized
 from the 'EMACS_INHIBIT_AUTOMATIC_NATIVE_COMPILATION' environment
 variable on Emacs startup.
 
@@ -1592,7 +1592,7 @@ package maintainers.
 
 +++
 *** New user option 'package-vc-selected-packages'
-By customising this user option you can specify specific packages to
+By customizing this user option you can specify specific packages to
 install.
 
 ** Emacs Sessions (Desktop)
@@ -2954,7 +2954,7 @@ normal.
 
 ---
 ** Themes have special autoload cookies.
-All build-in themes are scraped for ';;;###theme-autoload' cookies
+All built-in themes are scraped for ';;;###theme-autoload' cookies
 that are loaded along with the regular auto-loaded code.
 
 +++
diff --git a/etc/TODO b/etc/TODO
index cd02cf7023..bf30436270 100644
--- a/etc/TODO
+++ b/etc/TODO
@@ -1770,7 +1770,7 @@ The MPX code has not been tested under X toolkit or GTK+ 
2.x builds
 and is not expected to work there.
 
 ** Framework for doing animations
-Emacs does animations all over the place, usually "pluse" animations.
+Emacs does animations all over the place, usually "pulse" animations.
 These currently animate by waiting for a small but fixed amount of
 time between each redisplay, which causes screen tearing by not
 synchronizing with the vertical refresh.  Frame synchronization works
diff --git a/lisp/ChangeLog.15 b/lisp/ChangeLog.15
index 23e61ff787..9aa4caedfe 100644
--- a/lisp/ChangeLog.15
+++ b/lisp/ChangeLog.15
@@ -11955,7 +11955,7 @@
        (verilog-skip-backward-comments, verilog-skip-forward-comment-p):
        fix bug for /* / comments.
        (verilog-backward-syntactic-ws, verilog-forward-syntactic-ws):
-       Speed up and simplfy as this is never called with a bound.
+       Speed up and simplify as this is never called with a bound.
        (verilog-pretty-declarations): Enhance to line up declarations
        inside a parameter list, suggested by Alan Morgan.
        (verilog-pretty-expr): Tune assignment regular expression match
@@ -15783,7 +15783,7 @@
        * simple.el (with-wrapper-hook): Fix thinko.
 
        * hfy-cmap.el (hfy-rgb-file): Use locate-file.
-       (htmlfontify-load-rgb-file): Remove unnused var `ff'.
+       (htmlfontify-load-rgb-file): Remove unused var `ff'.
        Use with-current-buffer and string-to-number.
        (hfy-fallback-colour-values): Use assoc-string.
        * htmlfontify.el (hfy-face-to-css): Remove unused var `style'.
diff --git a/lisp/ChangeLog.16 b/lisp/ChangeLog.16
index f0a50bb4bc..ef59698317 100644
--- a/lisp/ChangeLog.16
+++ b/lisp/ChangeLog.16
@@ -2814,7 +2814,7 @@
 2012-12-12  Jonas Bernoulli  <jonas@bernoul.li>
 
        * emacs-lisp/eieio.el: Prettier object pretty-printing (bug#13115).
-       (eieio-override-prin1): Don't quote kewords and booleans.
+       (eieio-override-prin1): Don't quote keywords and booleans.
        (object-write) <eieio-default-superclass>: Don't put closing parens
        on new line, avoid needless empty lines, align values that are objects
        with the slot keyword (instead of beginning on the same line).
@@ -10765,7 +10765,7 @@
 
        * play/zone.el (zone-hiding-mode-line): Rename from
        zone-hiding-modeline.  All callers changed.
-       (zone): Remove unusued `modeline-hidden-level' property.
+       (zone): Remove unused `modeline-hidden-level' property.
 
        * progmodes/xscheme.el (xscheme-mode-line-initialize): Rename from
        xscheme-modeline-initialize.  All callers changed.
@@ -24104,7 +24104,7 @@
 
        * emacs-lisp/lisp-mode.el (eval-defun-2): Use eval-sexp-add-defvars.
 
-       * htmlfontify.el (hfy-etags-cmd): Remove inoperant eval-and-compile.
+       * htmlfontify.el (hfy-etags-cmd): Remove inoperative eval-and-compile.
        (hfy-e2x-etags-cmd, hfy-etags-cmd-alist-default)
        (hfy-etags-cmd-alist): Don't eval-and-compile any more.
 
diff --git a/lisp/ChangeLog.17 b/lisp/ChangeLog.17
index df731fe9ed..c494f43896 100644
--- a/lisp/ChangeLog.17
+++ b/lisp/ChangeLog.17
@@ -917,7 +917,7 @@
 
        * desktop.el (desktop-buffer-info): Write docstring.
        (desktop-buffer-info): Use `pushnew' instead of `add-to-list' and
-       unquote lamda.
+       unquote lambda.
 
        * emacs-lisp/package.el (package-refresh-contents): Update doc.
 
diff --git a/lisp/ChangeLog.7 b/lisp/ChangeLog.7
index 747a9ffab9..c81968e6ee 100644
--- a/lisp/ChangeLog.7
+++ b/lisp/ChangeLog.7
@@ -3147,20 +3147,20 @@
 
        * international/ccl.el: Change term translate-XXX-map to map-XXX
        throughout the file.  Change terms unify/unification to
-       translate/translation respectively throughtout the file.
+       translate/translation respectively throughout the file.
 
        * international/quail.el (quail-completion): Consecutive call of
        this command scrolls the Quail completion buffer.
 
        * international/mule.el: Change term unification to translation
-       throughtout the file.
+       throughout the file.
        (set-clipboard-coding-system): New function.
 
        * international/mule-conf.el: Change term unification to
-       translation throughtout the file.
+       translation throughout the file.
 
        * international/mule-util.el: Change term unification to
-       translation throughtout the file.
+       translation throughout the file.
 
 1998-05-17  Richard Stallman  <rms@psilocin.ai.mit.edu>
 
diff --git a/lisp/ansi-osc.el b/lisp/ansi-osc.el
index 499c9dce73..a8523fc9dc 100644
--- a/lisp/ansi-osc.el
+++ b/lisp/ansi-osc.el
@@ -141,7 +141,7 @@ and `shell-dirtrack-mode'."
 
 (defun ansi-osc-hyperlink-handler (_ text)
   "Create a hyperlink from an OSC 8 escape sequence.
-This function is intended to be included as an elemnt of the list
+This function is intended to be included as an element of the list
 that is the value of `ansi-osc-handlers'."
   (when ansi-osc-hyperlink--state
     (let ((start (car ansi-osc-hyperlink--state))
diff --git a/lisp/calendar/diary-lib.el b/lisp/calendar/diary-lib.el
index 98e91aaa75..0ebfc4bb8d 100644
--- a/lisp/calendar/diary-lib.el
+++ b/lisp/calendar/diary-lib.el
@@ -92,7 +92,7 @@ are holidays."
 This is used by `diary-pull-attrs' to fontify certain diary
 elements.  REGEXP is a regular expression to for, and SUBEXP is
 the numbered sub-expression to extract.  `diary-glob-file-regexp-prefix'
-is pre-pended to REGEXP for file-wide specifiers.  ATTRIBUTE
+is prepended to REGEXP for file-wide specifiers.  ATTRIBUTE
 specifies which face attribute (e.g. `:foreground') to modify, or
 that this is a face (`:face') to apply.  TYPE is the type of
 attribute being applied.  Available TYPES (see `diary-attrtype-convert')
@@ -109,7 +109,7 @@ are: `string', `symbol', `int', `tnil', `stringtnil'."
   :group 'diary)
 
 (defcustom diary-glob-file-regexp-prefix "^#"
-  "Regular expression pre-pended to `diary-face-attrs' for file-wide 
specifiers."
+  "Regular expression prepended to `diary-face-attrs' for file-wide 
specifiers."
   :type 'regexp
   :group 'diary)
 
diff --git a/lisp/cedet/ede.el b/lisp/cedet/ede.el
index e6bfd0b1e8..1118235757 100644
--- a/lisp/cedet/ede.el
+++ b/lisp/cedet/ede.el
@@ -598,7 +598,7 @@ an EDE controlled project."
      "\\.#"
      "~$"
      )
-  "List of file name patters that EDE will never ask about.")
+  "List of file name patterns that EDE will never ask about.")
 
 (defun ede-ignore-file (filename)
   "Should we ignore FILENAME?"
diff --git a/lisp/emacs-lisp/smie.el b/lisp/emacs-lisp/smie.el
index 61d52026b3..b86070deef 100644
--- a/lisp/emacs-lisp/smie.el
+++ b/lisp/emacs-lisp/smie.el
@@ -56,7 +56,7 @@
 ;; which includes a kind of tutorial to get started with SMIE:
 ;;
 ;;     SMIE: Weakness is Power!  Auto-indentation with incomplete information
-;;     Stefan Monnier, <Programming> Journal 2020, volumn 5, issue 1.
+;;     Stefan Monnier, <Programming> Journal 2020, volume 5, issue 1.
 ;;     doi: 10.22152/programming-journal.org/2021/5/1
 
 ;; A good background to understand the development (especially the parts
diff --git a/lisp/erc/ChangeLog.1 b/lisp/erc/ChangeLog.1
index 8fc9785430..89c24758cb 100644
--- a/lisp/erc/ChangeLog.1
+++ b/lisp/erc/ChangeLog.1
@@ -9372,8 +9372,8 @@
 
 2002-08-14  Mario Lang  <mlang@delysid.org>
 
-       * erc-button.el:
-       Try to be compatible to XEmacs regexp-opt. (Im going to quit this job 
if I find more of those damn differencies
+       * erc-button.el: Try to be compatible to XEmacs regexp-opt.  (I'm
+       going to quit this job if I find more of those damn differences.)
 
        * debian/README.Debian, debian/scripts/install:
        * Added info to README.Debian
diff --git a/lisp/eshell/esh-util.el b/lisp/eshell/esh-util.el
index ecb6888651..0ec11e8a0b 100644
--- a/lisp/eshell/esh-util.el
+++ b/lisp/eshell/esh-util.el
@@ -296,7 +296,7 @@ directories separated by `path-separator'."
      (if (listp path)
         path
        ;; Don't use `parse-colon-path' here, since we don't want
-       ;; the additonal translations it does on each element.
+       ;; the additional translations it does on each element.
        (split-string path (path-separator))))))
 
 (defun eshell-parse-colon-path (path-env)
diff --git a/lisp/gnus/ChangeLog.1 b/lisp/gnus/ChangeLog.1
index 1949f62609..002b7bcfff 100644
--- a/lisp/gnus/ChangeLog.1
+++ b/lisp/gnus/ChangeLog.1
@@ -910,7 +910,7 @@
 1998-07-11  Mike McEwan  <mike@lotusland.demon.co.uk>
 
        * gnus-agent.el (gnus-agent-fetch-headers): Note last fetched
-       headers per sesion to aid expiry in `headers only' groups.
+       headers per session to aid expiry in `headers only' groups.
 
        * gnus-agent.el (gnus-agent-expire): Update group info to add
        expired articles to list of read articles and prevent
diff --git a/lisp/gnus/ChangeLog.3 b/lisp/gnus/ChangeLog.3
index c33c76f68d..8087021a7c 100644
--- a/lisp/gnus/ChangeLog.3
+++ b/lisp/gnus/ChangeLog.3
@@ -4902,7 +4902,7 @@
 2011-07-31  Marcus Harnisch  <marcus.harnisch@gmx.net>  (tiny change)
 
        * gnus-art.el (gnus-article-stop-animations): Use `elt' instead of
-       `aref' for XEmacs compatibiltiy.
+       `aref' for XEmacs compatibility.
 
 2011-07-31  Lars Magne Ingebrigtsen  <larsi@gnus.org>
 
@@ -23276,7 +23276,7 @@
        Signal a specific `search-failed' rather than a generic `error'.
 
        * gnus-salt.el (gnus-pick-mouse-pick-region): Switch 1 => point-min.
-       (gnus-generate-vertical-tree): Usue `bobp' rather than compare to 1.
+       (gnus-generate-vertical-tree): Use `bobp' rather than compare to 1.
        (gnus-highlight-selected-tree): Use point-min rather than 1 and 2.
 
 2004-09-10  Simon Josefsson  <jas@extundo.com>
diff --git a/lisp/gnus/nnimap.el b/lisp/gnus/nnimap.el
index 73cd183a02..8392eb601f 100644
--- a/lisp/gnus/nnimap.el
+++ b/lisp/gnus/nnimap.el
@@ -238,7 +238,7 @@ during splitting, which may be slow."
       (with-current-buffer (nnimap-buffer)
        (erase-buffer)
         ;; If we have a lot of ranges, split them up to avoid
-        ;; generating too-long lines.  (The limit is 8192 octects,
+        ;; generating too-long lines.  (The limit is 8192 octets,
         ;; and this should guarantee that it's (much) shorter than
         ;; that.)  We don't stream the requests, since the server
         ;; may respond to the requests out-of-order:
diff --git a/lisp/icomplete.el b/lisp/icomplete.el
index 0a63e0a1dd..ef710d582d 100644
--- a/lisp/icomplete.el
+++ b/lisp/icomplete.el
@@ -228,7 +228,7 @@ the default otherwise."
 ;; Apropos `icomplete-scroll', we implement "scrolling icomplete"
 ;; within classic icomplete, which is "rotating", by contrast.
 ;;
-;; The two variables supporing this are
+;; The two variables supporting this are
 ;; `icomplete--scrolled-completions' and `icomplete--scrolled-past'.
 ;; They come into play when:
 ;;
diff --git a/lisp/language/ind-util.el b/lisp/language/ind-util.el
index 27facaa858..e2a21820f4 100644
--- a/lisp/language/ind-util.el
+++ b/lisp/language/ind-util.el
@@ -31,7 +31,7 @@
 
 ;;; Transliteration
 
-;; The followings provide the various transliteration schemes (such as
+;; The following provides the various transliteration schemes (such as
 ;; ITRANS, kyoto-harvard, and Aiba) of Indian scripts.  They are also
 ;; used in quail/indian.el for typing Indian script in Emacs.
 
@@ -638,7 +638,7 @@
 
 ;;; IS 13194 utilities
 
-;; The followings provide conversion between IS 13194 (ISCII) and UCS.
+;; The following provides conversion between IS 13194 (ISCII) and UCS.
 
 (dlet
     ;;Unicode vs IS13194  ;; only Devanagari is supported now.
diff --git a/lisp/leim/quail/indian.el b/lisp/leim/quail/indian.el
index 31a34bc1de..deef00b4c2 100644
--- a/lisp/leim/quail/indian.el
+++ b/lisp/leim/quail/indian.el
@@ -371,7 +371,7 @@ Full key sequences are listed below:")
 ;;; Tamil phonetic input method
 ;;;
 
-;; Define the input method straightaway.
+;; Define the input method straight away.
 (quail-define-package "tamil-phonetic" "Tamil" "ழ" t
  "Customisable Tamil phonetic input method.
 To change the translation rules of the input method, customize
diff --git a/lisp/leim/quail/misc-lang.el b/lisp/leim/quail/misc-lang.el
index 73287ee784..e9e11ac679 100644
--- a/lisp/leim/quail/misc-lang.el
+++ b/lisp/leim/quail/misc-lang.el
@@ -1526,7 +1526,7 @@
 
 (quail-define-package
  "gothic" "Gothic" "𐌰" nil
- "Input methid for the ancient Gothic script."
+ "Input method for the ancient Gothic script."
  nil t t t t nil nil nil nil nil t)
 
 (quail-define-rules
diff --git a/lisp/mh-e/ChangeLog.1 b/lisp/mh-e/ChangeLog.1
index 00e52df2bb..c7f5586140 100644
--- a/lisp/mh-e/ChangeLog.1
+++ b/lisp/mh-e/ChangeLog.1
@@ -8064,7 +8064,7 @@
 
        * mh-e.el (mh-last-msg): Add call to mh-recenter.
 
-2002-10-26  Peter S Galbraith  <psg@debia.org>
+2002-10-26  Peter S Galbraith  <psg@debian.org>
 
        * mh-comp.el (mh-search-addr-regexp, mh-re-search-to-cc): Remove
        `mh-re-search-to-cc' in favor of more generalized new function
diff --git a/lisp/org/ChangeLog.1 b/lisp/org/ChangeLog.1
index 836e1430df..4e1c44d2bc 100644
--- a/lisp/org/ChangeLog.1
+++ b/lisp/org/ChangeLog.1
@@ -881,7 +881,7 @@
        (org-table-find-dataline, org-table-move-row)
        (org-table-insert-hline, org-table-kill-row):
        Use `org-move-to-column' with the IGNORE-INVISIBLE arg set to `t', so
-       that abbreviated rows don't interfer with setting the cursor back
+       that abbreviated rows don't interfere with setting the cursor back
        at the correct position.
 
        * org.el (org-agenda-prepare-buffers): Use `save-excursion'
@@ -4724,7 +4724,7 @@
 2013-11-12  Michael Brand  <michael.ch.brand@gmail.com>
 
        * org-table.el (org-table-eval-formula): Align the arrow pointing
-       to the error in a Calc formula to the other fomula debugger logs.
+       to the error in a Calc formula to the other formula debugger logs.
 
        * org.el (org-link-escape-chars-browser): Add char double quote.
        (org-open-at-point): Use the constant
@@ -30650,7 +30650,7 @@
        and scheduling search.
 
        * org-exp.el (org-html-handle-time-stamps): No longer check for
-       the `org-export-with-timestamps' option, because the preprocesser
+       the `org-export-with-timestamps' option, because the preprocessor
        has taken care of this already.
 
        * org.el (org-entry-properties): Catch the case when this is
@@ -32411,7 +32411,7 @@
 
        * org-exp.el (org-print-icalendar-entries): Move the call to
        `org-diary-to-ical-string' out of the loop, and kill the buffer
-       afterwords.
+       afterwards.
 
        * org-remember.el (org-remember-visit-immediately):
        Position cursor after moving to the note.
diff --git a/lisp/progmodes/cc-bytecomp.el b/lisp/progmodes/cc-bytecomp.el
index 4b8154dafe..735d829769 100644
--- a/lisp/progmodes/cc-bytecomp.el
+++ b/lisp/progmodes/cc-bytecomp.el
@@ -287,7 +287,7 @@ perhaps a `cc-bytecomp-restore-environment' is forgotten 
somewhere"))
                    (cons cc-file cc-bytecomp-loaded-files))
              (cc-bytecomp-debug-msg
               "cc-bytecomp-load: Loading %S" cc-file)
-             ;; native-comp may async compile also intalled el.gz
+             ;; native-comp may async compile also installed el.gz
              ;; files therefore we may have to load here other el.gz.
              (load cc-part nil t)
              (cc-bytecomp-debug-msg
diff --git a/lisp/progmodes/cc-engine.el b/lisp/progmodes/cc-engine.el
index 0ea722a922..5d3d240886 100644
--- a/lisp/progmodes/cc-engine.el
+++ b/lisp/progmodes/cc-engine.el
@@ -7356,7 +7356,7 @@ multi-line strings (but not C++, for example)."
 (defun c-ml-string-opener-intersects-region (&optional start finish)
   ;; If any part of the region [START FINISH] is inside an ml-string opener,
   ;; return a dotted list of the start, end and double-quote position of that
-  ;; opener.  That list wlll not include any "context characters" before or
+  ;; opener.  That list will not include any "context characters" before or
   ;; after the opener.  If an opener is found, the match-data will indicate
   ;; it, with (match-string 1) being the entire delimiter, and (match-string
   ;; 2) the "main" double-quote.  Otherwise, the match-data is undefined.
diff --git a/lisp/progmodes/cc-mode.el b/lisp/progmodes/cc-mode.el
index 34ba97bb87..fb5ef69413 100644
--- a/lisp/progmodes/cc-mode.el
+++ b/lisp/progmodes/cc-mode.el
@@ -2505,7 +2505,7 @@ with // and /*, not more generic line and block comments."
                     (not (eobp)))
              (progn
                (c-forward-over-token)
-               ;; Cope with having POS withing a syntactically invalid
+               ;; Cope with having POS within a syntactically invalid
                ;; (...), by moving backward out of the parens and trying
                ;; again.
                (when (and (eq (char-before) ?\))
diff --git a/lisp/replace.el b/lisp/replace.el
index 8f81ec33a6..c7ae77d128 100644
--- a/lisp/replace.el
+++ b/lisp/replace.el
@@ -2818,7 +2818,7 @@ see the documentation of `replace-match' to find out how 
to simulate
 `case-replace'.
 
 This function returns nil if there were no matches to make, or
-the user cancelled the call.
+the user canceled the call.
 
 REPLACEMENTS is either a string, a list of strings, or a cons cell
 containing a function and its first argument.  The function is
diff --git a/nt/inc/ms-w32.h b/nt/inc/ms-w32.h
index 2dd9a9a476..98e31df70c 100644
--- a/nt/inc/ms-w32.h
+++ b/nt/inc/ms-w32.h
@@ -27,7 +27,7 @@ along with GNU Emacs.  If not, see 
<https://www.gnu.org/licenses/>.  */
 #include <mingw_time.h>
 
 /* MinGW-w64 gcc does not automotically define a macro for
-   differentiating it fom MinGW gcc. We need to test the presence of
+   differentiating it from MinGW gcc. We need to test the presence of
    __MINGW64_VERSION_MAJOR in _mingw.h: */
 #ifdef __MINGW32__
 # include <_mingw.h>
diff --git a/src/ChangeLog.13 b/src/ChangeLog.13
index 268a59219c..6eb54dfb2c 100644
--- a/src/ChangeLog.13
+++ b/src/ChangeLog.13
@@ -10183,7 +10183,7 @@
        (w32_wnd_proc): Handle bottom divider width.
        For WM_WINDOWPOSCHANGING return zero if we resize pixelwise.
        (Fx_create_frame): Default divider width parameters.
-       Caclulate sizes pixelwise.  Add vertical drag cursor support.
+       Calculate sizes pixelwise.  Add vertical drag cursor support.
        (x_create_tip_frame): Default divider widths to zero.
        Pixelize call to change_frame_size.
        (Fx_show_tip): Add handling of divider widths.  Pixelize window
diff --git a/src/ChangeLog.7 b/src/ChangeLog.7
index e893a2a6d8..9c6fd810d3 100644
--- a/src/ChangeLog.7
+++ b/src/ChangeLog.7
@@ -1215,19 +1215,19 @@
 
        * ccl.c: Change term translation to code conversion, then change
        terms unify/unification to translate/translation respectively
-       throughtout the file.
+       throughout the file.
 
        * charset.c: Change terms unify/unification to
-       translate/translation respectively throughtout the file.
+       translate/translation respectively throughout the file.
        (ONE_BYTE_CHAR_WIDTH): Delete unnecessary continuation line at the
        tail.
 
        * charset.h: Change terms unify/unification to
-       translate/translation respectively throughtout the file.
+       translate/translation respectively throughout the file.
        (GET_TRANSLATION_TABLE): Name changed from UNIFICATION_ID_TABLE.
 
        * coding.c: Change terms unify/unification to
-       translate/translation respectively throughtout the file.
+       translate/translation respectively throughout the file.
        (encode_coding_iso2022): Fix bug in encoding a text ending by a
        composite character.
        (check_composing_code): If we are decoding the last block of data,
diff --git a/src/itree.c b/src/itree.c
index 989173db4e..ae69c97d6d 100644
--- a/src/itree.c
+++ b/src/itree.c
@@ -70,7 +70,7 @@ along with GNU Emacs.  If not, see 
<http://www.gnu.org/licenses/>.  */
    but not the END.  The previous/next overlay change operations need
    to find the nearest point where there is *either* an interval BEG
    or END point, but there is no efficient way to narrow the search
-   space over END postions.
+   space over END positions.
 
    Consider the case where next-overlay-change is called at POS, all
    interval BEG positions are less than pos POS and all interval END
@@ -771,7 +771,7 @@ interval_tree_insert_fix (struct itree_tree *tree,
 }
 
 /* Insert a NODE into the TREE.
-   Note, that inserting a node twice results in undefined behaviour.  */
+   Note, that inserting a node twice results in undefined behavior.  */
 
 static void
 interval_tree_insert (struct itree_tree *tree, struct itree_node *node)
@@ -786,7 +786,7 @@ interval_tree_insert (struct itree_tree *tree, struct 
itree_node *node)
   struct itree_node *parent = NULL;
   struct itree_node *child = tree->root;
   uintmax_t otick = tree->otick;
-  /* It's the responsability of the caller to set `otick` on the node,
+  /* It's the responsibility of the caller to set `otick` on the node,
      to "confirm" that the begin/end fields are up to date.  */
   eassert (node->otick == otick);
 
diff --git a/src/w32fns.c b/src/w32fns.c
index 93b7f80f26..c7eddcba6d 100644
--- a/src/w32fns.c
+++ b/src/w32fns.c
@@ -8417,7 +8417,7 @@ a ShowWindow flag:
 
   current_dir = ENCODE_FILE (current_dir);
   /* Cannot use filename_to_utf16/ansi with DOCUMENT, since it could
-     be a URL that is not limited to MAX_PATH chararcters.  */
+     be a URL that is not limited to MAX_PATH characters.  */
   doclen = pMultiByteToWideChar (CP_UTF8, multiByteToWideCharFlags,
                                 SSDATA (document), -1, NULL, 0);
   doc_w = xmalloc (doclen * sizeof (wchar_t));
diff --git a/src/xterm.c b/src/xterm.c
index 0a25d7de05..b1e74199d7 100644
--- a/src/xterm.c
+++ b/src/xterm.c
@@ -18780,7 +18780,7 @@ handle_one_xevent (struct x_display_info *dpyinfo,
 
        /* If drag-and-drop or another modal dialog/menu is in
           progress, handle SelectionRequest events immediately, by
-          pushing it onto the selecction queue.  */
+          pushing it onto the selection queue.  */
 
        if (x_use_pending_selection_requests)
          {
diff --git a/test/src/buffer-tests.el b/test/src/buffer-tests.el
index 65a9945266..3fc52eaf8b 100644
--- a/test/src/buffer-tests.el
+++ b/test/src/buffer-tests.el
@@ -1724,7 +1724,7 @@ Test both rear-advance and non-rear-advance overlays."
 
 This test works best when Emacs is configured with
 --enable-checking=yes.  This is a little bit like fuzz testing,
-except this test has no way to reduce to a minimal failng test
+except this test has no way to reduce to a minimal failing test
 case.  Regardless, by exercising many corner cases bugs can be
 found using Emacs' internal consistency assertions."
   (let* (



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/lisp/progmodes/eglot.el b/lisp/progmodes/eglot.el
index a091d892b6..167fd129a5 100644
--- a/lisp/progmodes/eglot.el
+++ b/lisp/progmodes/eglot.el
@@ -56,7 +56,7 @@
 ;;   available as GNU ELPA :core packages.  Historically, a number of
 ;;   :core packages were added or reworked in Emacs to make this
 ;;   possible.  This principle should be upheld when adding new LSP
-;;   features or tweaking exising ones.  Design any new facilities in
+;;   features or tweaking existing ones.  Design any new facilities in
 ;;   a way that they could work in the absence of LSP or using some
 ;;   different protocol, then make sure Eglot can link up LSP
 ;;   information to it.
@@ -586,7 +586,7 @@ on unknown notifications and errors on unknown requests."))
 (cl-defmacro eglot--dbind (vars object &body body)
   "Destructure OBJECT, binding VARS in BODY.
 VARS is ([(INTERFACE)] SYMS...)
-Honour `eglot-strict-mode'."
+Honor `eglot-strict-mode'."
   (declare (indent 2) (debug (sexp sexp &rest form)))
   (let ((interface-name (if (consp (car vars))
                             (car (pop vars))))
@@ -613,7 +613,7 @@ Honour `eglot-strict-mode'."
 
 (cl-defmacro eglot--lambda (cl-lambda-list &body body)
   "Function of args CL-LAMBDA-LIST for processing INTERFACE objects.
-Honour `eglot-strict-mode'."
+Honor `eglot-strict-mode'."
   (declare (indent 1) (debug (sexp &rest form)))
   (let ((e (cl-gensym "jsonrpc-lambda-elem")))
     `(lambda (,e) (eglot--dbind ,cl-lambda-list ,e ,@body))))
@@ -1249,7 +1249,7 @@ This docstring appeases checkdoc, that's all."
     (setf (eglot--language-id server) language-id)
     (setf (eglot--inferior-process server) autostart-inferior-process)
     (run-hook-with-args 'eglot-server-initialized-hook server)
     ;; Now start the handshake.  To honour `eglot-sync-connect'
     ;; maybe-sync-maybe-async semantics we use `jsonrpc-async-request'
     ;; and mimic most of `jsonrpc-request'.
     (unwind-protect
@@ -1676,7 +1676,7 @@ against a variable's name.  Examples include the string
 Before Eglot starts \"managing\" a particular buffer, it
 opinionatedly sets some peripheral Emacs facilities, such as
 Flymake, Xref and Company.  These overriding settings help ensure
-consistent Eglot behaviour and only stay in place until
+consistent Eglot behavior and only stay in place until
 \"managing\" stops (usually via `eglot-shutdown'), whereupon the
 previous settings are restored.
 
@@ -3140,7 +3140,7 @@ Returns a list as described in docstring of 
`imenu--index-alist'."
           (unless (y-or-n-p
                    (format "[eglot] Server wants to edit:\n  %s\n Proceed? "
                            (mapconcat #'identity (mapcar #'car prepared) "\n  
")))
-            (jsonrpc-error "User cancelled server edit")))
+            (jsonrpc-error "User canceled server edit")))
       (cl-loop for edit in prepared
                for (path edits version) = edit
                do (with-current-buffer (find-file-noselect path)
@@ -1249,7 +1249,7 @@ This docstring appeases checkdoc, that's all."
     (setf (eglot--inferior-process server) autostart-inferior-process)
     (run-hook-with-args 'eglot-server-initialized-hook server)
-    ;; Now start the handshake.  To honour `eglot-sync-connect'
+    ;; Now start the handshake.  To honor `eglot-sync-connect'
     ;; maybe-sync-maybe-async semantics we use `jsonrpc-async-request'
     ;; and mimic most of `jsonrpc-request'.